+++
date = "2018-12-17"
weight = 100

title = "QA ImmutableRootfsTests"

aliases = [
    "/template_ostreetestcases.md",
    "/old-wiki/Template:OSTreeTestCases",
    "/template_immutablerootfstests.md",
    "/old-wiki/Template:ImmutableRootfsTests",
    "/old-wiki/QA/ImmutableRootfsTests"
]
+++

# Testing on a immutable rootfs

Tests should be self-contained and not require changes to the rootfs:
any change to the rootfs causes the tested system to diverge from the
one used in production, reducing the value of testing.

Changing the rootfs is also impossible or very cumbersome to do with
some deployment systems such as
[dm-verity](https://source.android.com/security/verifiedboot/dm-verity)
or [OSTree]( {{< ref "/docs/ostree.md" >}} ). Other systems may simply not ship
package management systems like `apt`/`dpkg` due to size constraints,
making package dependencies not viable.

Tests meant to be run on targets should then be self-sufficient and
should not require dependencies to be installed on the rootfs.

## Writing self-contained tests

  - Each tests is shipped in a separate git repository under the
    **[tests](https://gitlab.apertis.org/tests/)** GitLab group
  - Check existing tests like the **[D-Bus reply
    time](https://gitlab.apertis.org/tests/dbus-dos-reply-time/)** ones
    or the **[Canterbury](https://gitlab.apertis.org/tests/canterbury)**
    ones
  - Add a subtree of the
    [`common`](https://gitlab.apertis.org/tests/common) folder. For
    convenience, use the
    [`common-subtree.sh`](https://gitlab.apertis.org/tests/common/blob/master/common-subtree.sh)
    script to add a *git-subtree* into your repository:
        ../common/common-subtree.sh add
    See the
    [README](https://gitlab.apertis.org/tests/common/blob/master/README.md)
    for further details
  - For tests requiring additional binaries not shipped on the base
    image:
      - Add an
        [`external-binaries.cfg`](https://gitlab.apertis.org/tests/dbus-dos-reply-time/blob/master/external-binaries.cfg)
        file
      - Run the
        [`update_test_binaries.sh`](https://gitlab.apertis.org/tests/helper-tools/blob/master/update_test_binaries.sh)
        script:
            ./helper-tools/update_test_binaries.sh --repository <name-of-repo-under-gitlab-tests> --release 18.06 --dry-run
        `     This should add a commit with the binaries required by your test repository`
  - Tests should use compiled executables included with
    `update_test_binaries.sh` and/or POSIX shell scripts (avoid
    [bashisms](https://mywiki.wooledge.org/Bashism) and assume that
    `/bin/sh` points to `dash`)
  - Test the scripts in a `minimal` or `ostree` image
  - Add your repository to the [`test-repositories.txt`
    list](https://gitlab.apertis.org/tests/helper-tools/blob/master/test-repositories.txt)
    and Jenkins will keep the binaries automatically updated

## References

  - [Test cases](http://qa.apertis.org)
  - [Download Self Contained Test
    Data]( {{< ref "/qa/test_cases_guidelines.md#download-self-contained-test-data" >}} )
  - [Weekly test results]( {{< ref "/weeklytests.md" >}} )
  - [LQA Tool]( {{< ref "/qa/lqa.md" >}} )
  - [Personal LAVA Tests]( {{< ref "/qa/personal_lava_tests.md" >}} )