+++
date = "2018-10-03"
weight = 100

title = "System Image Setup"

aliases = [
    "/old-wiki/System_Image_Setup"
]
+++

Apertis is built as a few different system images:

  - *Target*: contains core OS plus middleware ready to be used as a
    base for other applications.
  - *Development*: Contains target image plus development tools and
    debugging libraries.
  - *SDK*: Contains development image plus XFCE4 and Eclipse
    environment.

These various images can be found at [1](https://images.apertis.org/)

Instructions on how to setup the various type of images follows below.

## Target images

Target and Development images can be used in virtualbox or on intel
hardware. This section handles only installation directly on hardware.
For installation in virtualbox, the same steps as for the SDK image can
be used with the target or development VDI image.

For use on hardware the `*img.gz` should be used and should be written
to an SD card or USB stick for booting on the target hardware. After
retrieving an image it can be written to an SD card as follows (assuming
*/dev/mmcblk0* is your first SD card):

` $ zcat apertis-15.06...img.gz | sudo dd of=/dev/mmcblk0 bs=8192`

## SDK Images

Retrieve the latest `*.vdi.gz` compressed VirtualBox disk image from the
[SDK image directory](https://images.apertis.org/).

Once downloading completes, decompress the archive. This will leave you
with a `*.vdi` disk image.

### Step 0: Install VirtualBox

Some features such as the integrated webcam require the last version
4.3.2. The packages are available on [the VirtualBox
website](https://www.virtualbox.org/wiki/Downloads).

  - Install VirtualBox 4.3.2
  - Install Oracle VM VirtualBox Extension Pack

In the menu **File**, **Preferences**, check that the extension is
correctly installed:

![<File:00-virtualbox-extensions.png>](/images/00-virtualbox-extensions.png)

### Step 1: Create a new virtual machine

Open VirtualBox and click the **New** button to create a new virtual
machine.

![<File:01-new-machine.png>](/images/01-new-machine.png)

Click **next**.

### Step 2: Name the machine

Provide a name for the new machine. We recommend including the date of
the image in case you create another SDK machines before deleting the
first.

Set the **Operating System** to Linux and **Version** to Ubuntu.

![<File:02-name-machine.png>](/images/02-name-machine.png)

Click **next**.

### Step 3: Set the memory allocation

Set the amount of memory to be allocated to this machine. We recommend
at least 2048 MB.

![<File:03-set-memory.png>](/images/03-set-memory.png)

Click **next**.

### Step 4: Select disk image and create

Click **Use existing hard disk** and the "select disk" button
(highlighted in the image below).

![<File:04-select-disk.png>](/images/04-select-disk.png)

Select the `*.vdi` disk image from before and click **Open**.

Click **next**. Click **Create**.

### Step 5: Configure CPUs

Locate the new machine on the left side of the main VirtualBox window.
Right-click on it and select **Settings**.

Click **System** on the left side, then the **Processor** tab. Set the
number of CPUs to 4 and ensure that the Execution Cap is 100(%).

![<File:05-set-cpus.png>](/images/05-set-cpus.png)

### Step 6: Configure Display

Click **Display** on the left side, then the **Video** tab. Set the
**Video Memory** to at least 12 MB.

Ensure that "Enable 3D Acceleration" and "Enable 2D Video Acceleration"
are both **unchecked** as they can interfere with proper graphics
operation within the SDK.

![<File:06-display-settings.png>](/images/06-display-settings.png)

Click **OK**.

### Step 7: Running machine and default desktop setup

In main VirtualBox window, double-click the name of the new machine. It
will open in a new window and boot the SDK.

Once booting is complete, you will see a desktop.

If prompted to select a desktop setup, choose **Use default config**

![<File:07-default-config.png>](/images/07-default-config.png)

The final desktop will look similar to the following image:

![<File:08-sdk-desktop.png>](/images/08-sdk-desktop.png)

### Step 8: Installing the guest extensions

In the menu **Devices**, choose **Insert Guest Additions CD image...**:

![<File:09-virtualbox-guest-additions.png>](/images/09-virtualbox-guest-additions.png)

The CD will be mounted in the virtual image. Then, as root:

`# /media/user/VBOXADDITIONS_4.3.2_90405/VBoxLinuxAdditions.run`

### Step 9: Misc devices

  - Webcam: the webcam works better when used through the VirtualBox
    integrated webcam rather than through USB.
      - Make sure USB WebCam is not assigned as "normal" USB device to
        VirtualBox: disable it in menu **Machine** -\> **Settings** -\>
        **USB**
      - Enable the webcam with menu **Devices** -\> **Webcams** -\>
        **integrated webcam**

<!-- end list -->

  - Bluetooth USB dongle: the USB device is plugged on the host but it
    can be made available to the VM through a VirtualBox USB filter:
    menu **Machine** -\> **Settings** -\> **USB**. Beware, a single
    device could have several ProductId: example with an Asus USB-BT211:

` `<code>`# lsusb # before the firmware is loaded`
` 0cf3:3000 Atheros Communications, Inc. AR3011 Bluetooth (no firmware)`
` # lsusb # after the firmware is loaded`
` 0cf3:3005 Atheros Communications, Inc. AR3011 Bluetooth`</code>

Therefore, you might have to change the VirtualBox USB filter to let
them all go to the VM by removing the ProductId:

![<File:virtualbox-usb-filter-details.png>](/images/virtualbox-usb-filter-details.png)